use std::{fs::File, io::Read};
use env_logger::Builder;
use log::{error, info, LevelFilter};

fn db(data: &[u8]) {
    
    /*let header_len = u32::from_le_bytes(data[4..8].try_into().expect("dddd"));
    let total_len = u32::from_le_bytes(data[8..12].try_into().expect("dddd"));
    let version = u32::from_le_bytes(data[16..20].try_into().expect("dddd"));
    let num_children = u32::from_le_bytes(data[20..24].try_into().expect("dddd"));
    info!("Header length: {}", header_len);
    info!("Total length: {}", total_len);
    info!("Version: {}", version);
    info!("Num children: {}", num_children);*/
    for i in 0..data.len() {
        let b = &data[i..i+4];
        if b == [109, 104, 105, 116] {
            info!("Found at: {:?}", i);
            let header_len = u32::from_le_bytes(data[i+4..i+8].try_into().expect("dddd"));
            let total_len = u32::from_le_bytes(data[i+8..i+12].try_into().expect("dddd"));
            let str_num = u32::from_le_bytes(data[i+12..i+16].try_into().expect("dddd"));
            let uuid = u32::from_le_bytes(data[i+16..i+20].try_into().expect("dddd"));
            let visibility = u32::from_le_bytes(data[i+20..i+24].try_into().expect("dddd"));
            let mut ft = data[i+24..i+28].to_vec();
            let type1 = data[i+29];
            let type2 = data[i+30];
            let dbid = u64::from_le_bytes(data[i+112..i+120].try_into().expect("sss"));
            ft.reverse();
            let file_type = String::from_utf8(ft).unwrap();
            info!("Header: {}, total: {}, strings: {}, uuid: {}, visibility: {}, file_type: {}, type1: {}, type2: {}, dbid: {}", 
                header_len, 
                total_len, 
                str_num, 
                uuid, 
                visibility,
                file_type,
                type1,
                type2,
                dbid);
        }
    }
}

fn main() {

    // Initialize the logger with 'info' as the default level
    Builder::new()
        .filter(None, LevelFilter::Info)
        .init();

    let mut f = File::open("ipod/iTunes/iTunesDB").unwrap();
    let mut buf = Vec::new();
    match f.read_to_end(&mut buf) {
        Ok(n) => {
            let data = &buf[..n];
            db(data);
        },
        Err(e) => {
            error!("Error: {}",e);
        }
    }
}
